import { Component, OnInit } from '@angular/core';
import { FormQuizService } from '../../../../services/form-quiz.service';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { MatDialogRef } from '@angular/material/dialog';

@Component({
    selector: 'app-form-create-quiz',
    templateUrl: './form-create-quiz.component.html',
    styleUrl: './form-create-quiz.component.css',
})
export class FormCreateQuizComponent implements OnInit {
    themes: { id: number; name: string }[] = [];

    categoryCtrl: any;
    nbQuestionCtrl: any;
    difficultyCtrl: any;
    form: any;

    constructor(
        private formQuizService: FormQuizService,
        private fb: FormBuilder,
        private dialogRef: MatDialogRef<FormCreateQuizComponent>,
        private router: Router
    ) {}
    categories: { id: number; name: string }[] = [];
    ngOnInit(): void {
        this.categoryCtrl = this.fb.control(null, []);
        this.nbQuestionCtrl = this.fb.control(0, [Validators.required, Validators.min(1), Validators.max(50)]);
        this.difficultyCtrl = this.fb.control(null, []);

        this.form = this.fb.group({
            category: this.categoryCtrl,
            nbQuestion: this.nbQuestionCtrl,
            difficulty: this.difficultyCtrl,
        });

        this.formQuizService.getCategory().subscribe({
            next: (data: any) => {
                this.categories = data['trivia_categories'];
            },
        });
    }

    submitForm(): void {
        if (this.form?.valid) {
            this.router.navigate(['/play-quiz'], {
                queryParams: {
                    category: this.form.value.category,
                    nbQuestions: this.form.value.nbQuestion,
                    difficulty: this.form.value.difficulty,
                },
            });
            this.dialogRef.close();
        }
    }

    handleClose() {
        this.dialogRef.close();
    }
}
