import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import Swal from 'sweetalert2';
import { QuestionService } from '../../../services/question.service';

@Component({
    selector: 'app-play-quiz',
    templateUrl: './play-quiz.component.html',
    styleUrl: './play-quiz.component.css',
})
export class PlayQuizComponent implements OnInit {
    constructor(
        private questionSerivce: QuestionService,
        private activatedRoute: ActivatedRoute,
        private router: Router,
        private cdr: ChangeDetectorRef
    ) {}
    isLoading: boolean = false;
    quiz: any = [];
    actualQuestion: any;
    actualQuestionIndex: number = -1;
    score: number = 0;
    showNextQuestion: boolean = false;
    ngOnInit(): void {
        this.isLoading = true;
        this.activatedRoute.queryParams.subscribe((params) => {
            const nbQuestions = params['nbQuestions'];
            const difficulty = params['difficulty'];
            const category = params['category'];
            this.questionSerivce.createQuiz(nbQuestions, category, difficulty).subscribe({
                next: (data: any) => {
                    console.log('data : ', data);
                    this.quiz = data;
                    this.nextQuestion();
                    this.isLoading = false;
                },
            });
        });
    }

    nextQuestion() {
        if (this.actualQuestionIndex === this.quiz.questionIndex + this.quiz.questions.length - 1) {
            Swal.fire({
                title: 'Quiz finished !',
                text: 'Want a rematch ?',
                showDenyButton: true,
                showCancelButton: false,
                confirmButtonText: 'Play again',
                confirmButtonColor: '#7e3f97',
                denyButtonColor: '#D6BAEC',
                denyButtonText: `Back home`,
            }).then((result) => {
                if (result.isConfirmed) {
                    this.actualQuestionIndex = -1;
                    this.nextQuestion();
                } else if (result.isDenied) {
                    this.router.navigate(['/']);
                }
            });
        } else {
            this.actualQuestionIndex++;
            this.actualQuestion = this.quiz.questions[this.actualQuestionIndex];
            this.showNextQuestion = false;
        }
    }

    getAnswerBound = this.getAnswer.bind(this);

    async getAnswer(id_tested_answer: number): Promise<number> {
        this.showNextQuestion = true;
        this.cdr.detectChanges();
        return 0;
    }

    // randomArray(array: any[]): void {
    //     for (let i = array.length - 1; i > 0; i--) {
    //         const j = Math.floor(Math.random() * (i + 1));
    //         [array[i], array[j]] = [array[j], array[i]];
    //     }
    // }
}
